@@ -753,6 +753,8 @@ class CameraDevice(Protocol):
     on_siren_detected: HybridObservable[SirenState]
     on_battery_changed: HybridObservable[BatteryState]
 
+    logger: "LoggerService"
+
     async def snapshot(self, force_new: Optional[bool] = None) -> Optional[bytes]: ...
 
     @overload
@@ -1133,6 +1135,9 @@ class AudioDetectionPlugin(BasePlugin):
     ) -> AudioDetectionPluginResponse: ...
 
 
+LoggerLevel = Literal["error", "warn", "info", "debug", "trace", "attention", "success"]
+
+
 @runtime_checkable
 class LoggerService(Protocol):
     def log(self, *args: Any) -> None: ...
@@ -1141,6 +1146,7 @@ class LoggerService(Protocol):
     def debug(self, *args: Any) -> None: ...
     def trace(self, *args: Any) -> None: ...
     def attention(self, *args: Any) -> None: ...
+    def success(self, *args: Any) -> None: ...
 
 
 APIEventType = Literal["finishLaunching", "shutdown"]
